Struct Cr2
#[repr(transparent)]pub struct Cr2(pub u32);Expand description
CR2 register.
Tuple Fields
0: u32Implementations
impl Cr2
impl Cr2
pub const fn pvde(&self) -> bool
pub const fn pvde(&self) -> bool
PVDE Programmable Voltage Detector Enable When this bit is set the Power Voltage Detector is enabled.
pub fn set_pvde(&mut self, val: bool)
pub fn set_pvde(&mut self, val: bool)
PVDE Programmable Voltage Detector Enable When this bit is set the Power Voltage Detector is enabled.
pub const fn pvdls(&self) -> Pvdls
pub const fn pvdls(&self) -> Pvdls
PVDLS[2:0] Programmable Voltage Detector Level selection then PVDO=1).
pub fn set_pvdls(&mut self, val: Pvdls)
pub fn set_pvdls(&mut self, val: Pvdls)
PVDLS[2:0] Programmable Voltage Detector Level selection then PVDO=1).
pub const fn dbgret(&self) -> bool
pub const fn dbgret(&self) -> bool
DBGRET: PA2 and PA3 retention enable after DEEPSTOP 0: PA2, PA3 don’t retain their status exiting from DEEPSTOP. (default) 1: PA2, PA3 retain their status exiting from DEEPSTOP.
pub fn set_dbgret(&mut self, val: bool)
pub fn set_dbgret(&mut self, val: bool)
DBGRET: PA2 and PA3 retention enable after DEEPSTOP 0: PA2, PA3 don’t retain their status exiting from DEEPSTOP. (default) 1: PA2, PA3 retain their status exiting from DEEPSTOP.
pub fn set_ramret1(&mut self, val: bool)
pub fn set_ramret1(&mut self, val: bool)
Enables the RAM2 bank retention in DEEPSTOP mode.
pub fn set_ramret2(&mut self, val: bool)
pub fn set_ramret2(&mut self, val: bool)
Enables the RAM2 bank retention in DEEPSTOP mode.
pub fn set_ramret3(&mut self, val: bool)
pub fn set_ramret3(&mut self, val: bool)
Enables the RAM3 bank retention in DEEPSTOP mode.
pub const fn gpioret(&self) -> bool
pub const fn gpioret(&self) -> bool
GPIORET: GPIO retention enable. 0: GPIO don’t retain their status during DEEPSTOP and exiting from DEEPSTOP (default) 1: GPIO retain their status during DEEPSTOP and exiting from DEEPSTOP. Note: it’s mandatory to ensure this bit is set before entering DEEPSTOP unless DBRG.DEEPSTOP2 bit is set.
pub fn set_gpioret(&mut self, val: bool)
pub fn set_gpioret(&mut self, val: bool)
GPIORET: GPIO retention enable. 0: GPIO don’t retain their status during DEEPSTOP and exiting from DEEPSTOP (default) 1: GPIO retain their status during DEEPSTOP and exiting from DEEPSTOP. Note: it’s mandatory to ensure this bit is set before entering DEEPSTOP unless DBRG.DEEPSTOP2 bit is set.
pub const fn lsilpmufen(&self) -> bool
pub const fn lsilpmufen(&self) -> bool
LSI LPMU force enable.
pub fn set_lsilpmufen(&mut self, val: bool)
pub fn set_lsilpmufen(&mut self, val: bool)
LSI LPMU force enable.