stm32-metapac

Crates

git

Versions

stm32wb09ke

Flavors

Cr4

Struct Cr4 

#[repr(transparent)]
pub struct Cr4(pub u32);
CR4 register.

Tuple Fields

0: u32

Implementations



impl Cr4

pub const fn wup0(&self) -> Wup

WUP0 Wake-up Line Polarity 0 (PB0) This bit defines the polarity used for event detection on external wake-up line 0.

pub fn set_wup0(&mut self, val: Wup)

WUP0 Wake-up Line Polarity 0 (PB0) This bit defines the polarity used for event detection on external wake-up line 0.

pub const fn wup1(&self) -> Wup

WUP1 Wake-up Line Polarity 1 (PB1) This bit defines the polarity used for event detection on external wake-up line 1.

pub fn set_wup1(&mut self, val: Wup)

WUP1 Wake-up Line Polarity 1 (PB1) This bit defines the polarity used for event detection on external wake-up line 1.

pub const fn wup2(&self) -> Wup

WUP2 Wake-up Line Polarity 2 (PB2) This bit defines the polarity used for event detection on external wake-up line 2.

pub fn set_wup2(&mut self, val: Wup)

WUP2 Wake-up Line Polarity 2 (PB2) This bit defines the polarity used for event detection on external wake-up line 2.

pub const fn wup3(&self) -> Wup

WUP3 Wake-up Line Polarity 3 (PB3) This bit defines the polarity used for event detection on external wake-up line 3.

pub fn set_wup3(&mut self, val: Wup)

WUP3 Wake-up Line Polarity 3 (PB3) This bit defines the polarity used for event detection on external wake-up line 3.

pub const fn wup4(&self) -> Wup

WUP4 Wake-up Line Polarity 4 (PB4) This bit defines the polarity used for event detection on external wake-up line 4.

pub fn set_wup4(&mut self, val: Wup)

WUP4 Wake-up Line Polarity 4 (PB4) This bit defines the polarity used for event detection on external wake-up line 4.

pub const fn wup5(&self) -> Wup

WUP5 Wake-up Line Polarity 5 (PB5) This bit defines the polarity used for event detection on external wake-up line 5.

pub fn set_wup5(&mut self, val: Wup)

WUP5 Wake-up Line Polarity 5 (PB5) This bit defines the polarity used for event detection on external wake-up line 5.

pub const fn wup6(&self) -> Wup

WUP6 Wake-up Line Polarity 6 (PB6) This bit defines the polarity used for event detection on external wake-up line 6.

pub fn set_wup6(&mut self, val: Wup)

WUP6 Wake-up Line Polarity 6 (PB6) This bit defines the polarity used for event detection on external wake-up line 6.

pub const fn wup7(&self) -> Wup

WUP7 Wake-up Line Polarity 7 (PB7) This bit defines the polarity used for event detection on external wake-up line 7.

pub fn set_wup7(&mut self, val: Wup)

WUP7 Wake-up Line Polarity 7 (PB7) This bit defines the polarity used for event detection on external wake-up line 7.

pub const fn wup8(&self) -> Wup

WUP8 Wake-up Line Polarity 8 (PA8) This bit defines the polarity used for event detection on external wake-up line 8.

pub fn set_wup8(&mut self, val: Wup)

WUP8 Wake-up Line Polarity 8 (PA8) This bit defines the polarity used for event detection on external wake-up line 8.

pub const fn wup9(&self) -> Wup

WUP9 Wake-up Line Polarity 9 (PA9) This bit defines the polarity used for event detection on external wake-up line 9.

pub fn set_wup9(&mut self, val: Wup)

WUP9 Wake-up Line Polarity 9 (PA9) This bit defines the polarity used for event detection on external wake-up line 9.

pub const fn wup10(&self) -> Wup

WUP10 Wake-up Line Polarity 10 (PA10) This bit defines the polarity used for event detection on external wake-up line 10.

pub fn set_wup10(&mut self, val: Wup)

WUP10 Wake-up Line Polarity 10 (PA10) This bit defines the polarity used for event detection on external wake-up line 10.

pub const fn wup11(&self) -> Wup

WUP11 Wake-up Line Polarity 11 (PA11) This bit defines the polarity used for event detection on external wake-up line 11.

pub fn set_wup11(&mut self, val: Wup)

WUP11 Wake-up Line Polarity 11 (PA11) This bit defines the polarity used for event detection on external wake-up line 11.