stm32-metapac

Crates

git

Versions

stm32wb09ke

Flavors

Cr7

Struct Cr7 

#[repr(transparent)]
pub struct Cr7(pub u32);
CR7 register.

Tuple Fields

0: u32

Implementations



impl Cr7

pub const fn wup12(&self) -> Wup

WUP12 Wake-up Line Polarity 12 (PA0) This bit defines the polarity used for event detection on external wake-up line 12.

pub fn set_wup12(&mut self, val: Wup)

WUP12 Wake-up Line Polarity 12 (PA0) This bit defines the polarity used for event detection on external wake-up line 12.

pub const fn wup13(&self) -> Wup

WUP13 Wake-up Line Polarity 13 (PA1) This bit defines the polarity used for event detection on external wake-up line 13.

pub fn set_wup13(&mut self, val: Wup)

WUP13 Wake-up Line Polarity 13 (PA1) This bit defines the polarity used for event detection on external wake-up line 13.

pub const fn wup14(&self) -> Wup

WUP14 Wake-up Line Polarity 14 (PA2) This bit defines the polarity used for event detection on external wake-up line 14.

pub fn set_wup14(&mut self, val: Wup)

WUP14 Wake-up Line Polarity 14 (PA2) This bit defines the polarity used for event detection on external wake-up line 14.

pub const fn wup15(&self) -> Wup

WUP15 Wake-up Line Polarity 15 (PA3) This bit defines the polarity used for event detection on external wake-up line 15.

pub fn set_wup15(&mut self, val: Wup)

WUP15 Wake-up Line Polarity 15 (PA3) This bit defines the polarity used for event detection on external wake-up line 15.

pub const fn wup16(&self) -> Wup

WUP16 Wake-up Line Polarity 16 (PB12) This bit defines the polarity used for event detection on external wake-up line 16.

pub fn set_wup16(&mut self, val: Wup)

WUP16 Wake-up Line Polarity 16 (PB12) This bit defines the polarity used for event detection on external wake-up line 16.

pub const fn wup17(&self) -> Wup

WUP17 Wake-up Line Polarity 17 (PB13) This bit defines the polarity used for event detection on external wake-up line 17.

pub fn set_wup17(&mut self, val: Wup)

WUP17 Wake-up Line Polarity 17 (PB13) This bit defines the polarity used for event detection on external wake-up line 17.

pub const fn wup18(&self) -> Wup

WUP18 Wake-up Line Polarity 18 (PB14) This bit defines the polarity used for event detection on external wake-up line 18.

pub fn set_wup18(&mut self, val: Wup)

WUP18 Wake-up Line Polarity 18 (PB14) This bit defines the polarity used for event detection on external wake-up line 18.

pub const fn wup19(&self) -> Wup

WUP19 Wake-up Line Polarity 19 (PB15) This bit defines the polarity used for event detection on external wake-up line 19.

pub fn set_wup19(&mut self, val: Wup)

WUP19 Wake-up Line Polarity 19 (PB15) This bit defines the polarity used for event detection on external wake-up line 19.

pub const fn wup20(&self) -> bool

Wake-up polarity for PB8 IO event.

pub fn set_wup20(&mut self, val: bool)

Wake-up polarity for PB8 IO event.

pub const fn wup21(&self) -> bool

Wake-up polarity for PB9 IO event.

pub fn set_wup21(&mut self, val: bool)

Wake-up polarity for PB9 IO event.

pub const fn wup22(&self) -> bool

Wake-up polarity for PB10 IO event.

pub fn set_wup22(&mut self, val: bool)

Wake-up polarity for PB10 IO event.

pub const fn wup23(&self) -> bool

Wake-up polarity for PB11 IO event.

pub fn set_wup23(&mut self, val: bool)

Wake-up polarity for PB11 IO event.

pub const fn wup24(&self) -> bool

Wake-up polarity for PB12 IO event.

pub fn set_wup24(&mut self, val: bool)

Wake-up polarity for PB12 IO event.

pub const fn wup25(&self) -> bool

Wake-up polarity for PB13 IO event.

pub fn set_wup25(&mut self, val: bool)

Wake-up polarity for PB13 IO event.

pub const fn wup26(&self) -> bool

Wake-up polarity for PB14 IO event.

pub fn set_wup26(&mut self, val: bool)

Wake-up polarity for PB14 IO event.

pub const fn wup27(&self) -> bool

Wake-up polarity for PB15 IO event.

pub fn set_wup27(&mut self, val: bool)

Wake-up polarity for PB15 IO event.