Struct Sr1
#[repr(transparent)]pub struct Sr1(pub u32);Expand description
SR1 register.
Tuple Fields
0: u32Implementations
impl Sr1
impl Sr1
pub const fn wuf0(&self) -> Wuf
pub const fn wuf0(&self) -> Wuf
WUF0 WakeUp Flag 0 (PB0) This bit is set when a wakeup is detected on wakeup line 0. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf0(&mut self, val: Wuf)
pub fn set_wuf0(&mut self, val: Wuf)
WUF0 WakeUp Flag 0 (PB0) This bit is set when a wakeup is detected on wakeup line 0. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf1(&self) -> Wuf
pub const fn wuf1(&self) -> Wuf
WUF1 WakeUp Flag 1 (PB1) This bit is set when a wakeup is detected on wakeup line 1. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf1(&mut self, val: Wuf)
pub fn set_wuf1(&mut self, val: Wuf)
WUF1 WakeUp Flag 1 (PB1) This bit is set when a wakeup is detected on wakeup line 1. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf2(&self) -> Wuf
pub const fn wuf2(&self) -> Wuf
WUF2 WakeUp Flag 2 (PB2) This bit is set when a wakeup is detected on wakeup line 2. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf2(&mut self, val: Wuf)
pub fn set_wuf2(&mut self, val: Wuf)
WUF2 WakeUp Flag 2 (PB2) This bit is set when a wakeup is detected on wakeup line 2. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf3(&self) -> Wuf
pub const fn wuf3(&self) -> Wuf
WUF3 WakeUp Flag 3 (PB3) This bit is set when a wakeup is detected on wakeup line 3. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf3(&mut self, val: Wuf)
pub fn set_wuf3(&mut self, val: Wuf)
WUF3 WakeUp Flag 3 (PB3) This bit is set when a wakeup is detected on wakeup line 3. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf4(&self) -> Wuf
pub const fn wuf4(&self) -> Wuf
WUF4 WakeUp Flag 4 (PB4) This bit is set when a wakeup is detected on wakeup line 4. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf4(&mut self, val: Wuf)
pub fn set_wuf4(&mut self, val: Wuf)
WUF4 WakeUp Flag 4 (PB4) This bit is set when a wakeup is detected on wakeup line 4. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf5(&self) -> Wuf
pub const fn wuf5(&self) -> Wuf
WUF5 WakeUp Flag 5 (PB5) This bit is set when a wakeup is detected on wakeup line 5. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf5(&mut self, val: Wuf)
pub fn set_wuf5(&mut self, val: Wuf)
WUF5 WakeUp Flag 5 (PB5) This bit is set when a wakeup is detected on wakeup line 5. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf6(&self) -> Wuf
pub const fn wuf6(&self) -> Wuf
WUF6 WakeUp Flag 6 (PB6) This bit is set when a wakeup is detected on wakeup line 6. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf6(&mut self, val: Wuf)
pub fn set_wuf6(&mut self, val: Wuf)
WUF6 WakeUp Flag 6 (PB6) This bit is set when a wakeup is detected on wakeup line 6. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf7(&self) -> Wuf
pub const fn wuf7(&self) -> Wuf
WUF7 WakeUp Flag 7 (PB7) This bit is set when a wakeup is detected on wakeup line 7. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf7(&mut self, val: Wuf)
pub fn set_wuf7(&mut self, val: Wuf)
WUF7 WakeUp Flag 7 (PB7) This bit is set when a wakeup is detected on wakeup line 7. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf8(&self) -> Wuf
pub const fn wuf8(&self) -> Wuf
WUF8 WakeUp Flag 8 (PA8) This bit is set when a wakeup is detected on wakeup line 8. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf8(&mut self, val: Wuf)
pub fn set_wuf8(&mut self, val: Wuf)
WUF8 WakeUp Flag 8 (PA8) This bit is set when a wakeup is detected on wakeup line 8. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf9(&self) -> Wuf
pub const fn wuf9(&self) -> Wuf
WUF9 WakeUp Flag 9 (PA9) This bit is set when a wakeup is detected on wakeup line 9. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf9(&mut self, val: Wuf)
pub fn set_wuf9(&mut self, val: Wuf)
WUF9 WakeUp Flag 9 (PA9) This bit is set when a wakeup is detected on wakeup line 9. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf10(&self) -> Wuf
pub const fn wuf10(&self) -> Wuf
WUF10 WakeUp Flag 10 (PA10) This bit is set when a wakeup is detected on wakeup line 10. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf10(&mut self, val: Wuf)
pub fn set_wuf10(&mut self, val: Wuf)
WUF10 WakeUp Flag 10 (PA10) This bit is set when a wakeup is detected on wakeup line 10. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wuf11(&self) -> Wuf
pub const fn wuf11(&self) -> Wuf
WUF11 WakeUp Flag 11 (PA11) This bit is set when a wakeup is detected on wakeup line 11. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub fn set_wuf11(&mut self, val: Wuf)
pub fn set_wuf11(&mut self, val: Wuf)
WUF11 WakeUp Flag 11 (PA11) This bit is set when a wakeup is detected on wakeup line 11. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.
pub const fn wblef(&self) -> bool
pub const fn wblef(&self) -> bool
WBLEF: BLE wakeup flag. 0: no wakeup from BLE occurred since last clear. 1: a wakeup from BLE occurred since last clear. Cleared by writing 1 in this bit.
pub fn set_wblef(&mut self, val: bool)
pub fn set_wblef(&mut self, val: bool)
WBLEF: BLE wakeup flag. 0: no wakeup from BLE occurred since last clear. 1: a wakeup from BLE occurred since last clear. Cleared by writing 1 in this bit.
pub const fn wblehcpuf(&self) -> bool
pub const fn wblehcpuf(&self) -> bool
WBLEHCPUF: BLE Host CPU wakeup flag. 0: no wakeup from BLE Host CPU occurred since last clear. 1: a wakeup from BLE Host CPU occurred since last clear. Cleared by writing 1 in this bit.
pub fn set_wblehcpuf(&mut self, val: bool)
pub fn set_wblehcpuf(&mut self, val: bool)
WBLEHCPUF: BLE Host CPU wakeup flag. 0: no wakeup from BLE Host CPU occurred since last clear. 1: a wakeup from BLE Host CPU occurred since last clear. Cleared by writing 1 in this bit.
pub const fn iwuf2(&self) -> bool
pub const fn iwuf2(&self) -> bool
IWUF2: Internal wakeup 2 flag (LPUART). 0: no wakeup from LPUART occurred since last clear. 1: a wakeup from LPUART occurred since last clear. Note: The user must clear the LPUART wakeup flag inside the LPUART IP to clear this bit (mirror of the LPUART wakeup line on the PWRC block).
pub fn set_iwuf2(&mut self, val: bool)
pub fn set_iwuf2(&mut self, val: bool)
IWUF2: Internal wakeup 2 flag (LPUART). 0: no wakeup from LPUART occurred since last clear. 1: a wakeup from LPUART occurred since last clear. Note: The user must clear the LPUART wakeup flag inside the LPUART IP to clear this bit (mirror of the LPUART wakeup line on the PWRC block).
pub const fn iwuf(&self) -> bool
pub const fn iwuf(&self) -> bool
IWUF: Internal wakeup flag (RTC). 0: no wakeup from RTC occurred since last clear. 1: a wakeup from RTC occurred since last clear. Note: The user must clear the RTC wakeup flag inside the RTC IP to clear this bit (mirror of the RTC wakeup line on the PWRC block).
pub fn set_iwuf(&mut self, val: bool)
pub fn set_iwuf(&mut self, val: bool)
IWUF: Internal wakeup flag (RTC). 0: no wakeup from RTC occurred since last clear. 1: a wakeup from RTC occurred since last clear. Note: The user must clear the RTC wakeup flag inside the RTC IP to clear this bit (mirror of the RTC wakeup line on the PWRC block).