Struct Cr1
#[repr(transparent)]pub struct Cr1(pub u32);Expand description
CR1 register.
Tuple Fields
0: u32Implementations
impl Cr1
impl Cr1
pub const fn lpms(&self) -> Lpms
pub const fn lpms(&self) -> Lpms
LPMS Low Power Mode Selection Selection of the low power mode entered when CPU enters DEEP SLEEP mode and BLE is rdy2sleep.
pub fn set_lpms(&mut self, val: Lpms)
pub fn set_lpms(&mut self, val: Lpms)
LPMS Low Power Mode Selection Selection of the low power mode entered when CPU enters DEEP SLEEP mode and BLE is rdy2sleep.
pub const fn ensdnbor(&self) -> Ensdnbor
pub const fn ensdnbor(&self) -> Ensdnbor
ENSDNBOR: Enable BOR supply monitoring during shutdown mode.
pub fn set_ensdnbor(&mut self, val: Ensdnbor)
pub fn set_ensdnbor(&mut self, val: Ensdnbor)
ENSDNBOR: Enable BOR supply monitoring during shutdown mode.
pub const fn ibias_run_auto(&self) -> bool
pub const fn ibias_run_auto(&self) -> bool
IBIAS_RUN_AUTO: Enable automatic IBIAS control during RUN/DEEPSTOP mode. 0: IBIAS control is manual (and controlled by IBIAS_RUN_STATE register) 1: IBIAS control is automatic (default).
pub fn set_ibias_run_auto(&mut self, val: bool)
pub fn set_ibias_run_auto(&mut self, val: bool)
IBIAS_RUN_AUTO: Enable automatic IBIAS control during RUN/DEEPSTOP mode. 0: IBIAS control is manual (and controlled by IBIAS_RUN_STATE register) 1: IBIAS control is automatic (default).
pub const fn ibias_run_state(&self) -> bool
pub const fn ibias_run_state(&self) -> bool
IBIAS_RUN_STATE: Enable/Disable IBIAS during RUN mode when automatic mode is disabled. 0: IBIAS control is disabled (default). 1: IBIAS control is enabled.
pub fn set_ibias_run_state(&mut self, val: bool)
pub fn set_ibias_run_state(&mut self, val: bool)
IBIAS_RUN_STATE: Enable/Disable IBIAS during RUN mode when automatic mode is disabled. 0: IBIAS control is disabled (default). 1: IBIAS control is enabled.
pub fn set_enborh(&mut self, val: Enborh)
pub fn set_enborh(&mut self, val: Enborh)
ENBORH: enable BORH configuration.
pub fn set_selborh(&mut self, val: Selborh)
pub fn set_selborh(&mut self, val: Selborh)
SELBORH[1:0]: BORH selection of Vbor threshold.
pub const fn enborl(&self) -> bool
pub const fn enborl(&self) -> bool
ENBORL: Enable BORL reset supervising during RUN mode. 0: No BORL is monitored during RUN mode. 1: BORL is monitored during RUN mode (a POR reset will happen if VDDIO goes below 1.6V during RUN mode) (default). Note: Enabling this feature prevents blocking the device if VDDIO goes below supported voltages during RUN.
pub fn set_enborl(&mut self, val: bool)
pub fn set_enborl(&mut self, val: bool)
ENBORL: Enable BORL reset supervising during RUN mode. 0: No BORL is monitored during RUN mode. 1: BORL is monitored during RUN mode (a POR reset will happen if VDDIO goes below 1.6V during RUN mode) (default). Note: Enabling this feature prevents blocking the device if VDDIO goes below supported voltages during RUN.